@@ -1,7 +1,5 @@
 """Define the Component class."""
 
-from __future__ import division
-
 from collections import OrderedDict, Counter, defaultdict
 
 # note: this is a Python 3.3 change, clean this up for OpenMDAO 3.x
@@ -11,7 +9,6 @@ except ImportError:
     from collections import Iterable
 
 from itertools import product
-from six import string_types, iteritems, itervalues
 
 import numpy as np
 from numpy import ndarray, isscalar, atleast_1d, atleast_2d, promote_types
@@ -26,7 +23,7 @@ from openmdao.utils.units import valid_units
 from openmdao.utils.name_maps import rel_key2abs_key, abs_key2rel_key, rel_name2abs_name
 from openmdao.utils.mpi import MPI
 from openmdao.utils.general_utils import format_as_float_or_array, ensure_compatible, \
-    warn_deprecation, find_matches, simple_warning, make_set
+    find_matches, simple_warning, make_set
 import openmdao.utils.coloring as coloring_mod
 
 
@@ -124,34 +121,6 @@ class Component(System):
                              desc='True if the component has variables that are distributed '
                                   'across multiple processes.')
 
-    @property
-    def distributed(self):
-        """
-        Provide 'distributed' property for backwards compatibility.
-
-        Returns
-        -------
-        bool
-            reference to the 'distributed' option.
-        """
-        warn_deprecation("The 'distributed' property provides backwards compatibility "
-                         "with OpenMDAO <= 2.4.0 ; use the 'distributed' option instead.")
-        return self.options['distributed']
-
-    @distributed.setter
-    def distributed(self, val):
-        """
-        Provide for setting of the 'distributed' property for backwards compatibility.
-
-        Parameters
-        ----------
-        val : bool
-            True if the component has variables that are distributed across multiple processes.
-        """
-        warn_deprecation("The 'distributed' property provides backwards compatibility "
-                         "with OpenMDAO <= 2.4.0 ; use the 'distributed' option instead.")
-        self.options['distributed'] = val
-
     def setup(self):
         """
         Declare inputs and outputs.
@@ -247,7 +216,7 @@ class Component(System):
         # wasn't.  If declare partials wasn't called, call it with of='*' and wrt='*' so we'll
         # have something to color.
         if self._coloring_info['coloring'] is not None:
-            for key, meta in iteritems(self._declared_partials):
+            for key, meta in self._declared_partials.items():
                 if 'method' in meta and meta['method'] is not None:
                     break
             else:
@@ -305,7 +274,7 @@ class Component(System):
                 # Compute abs2meta
                 abs2meta[abs_name] = metadata
 
-            for prom_name, val in iteritems(self._var_discrete[type_]):
+            for prom_name, val in self._var_discrete[type_].items():
                 abs_name = prefix + prom_name
 
                 # Compute allprocs_abs_names_discrete
@@ -402,7 +371,7 @@ class Component(System):
         self._subjacs_info = {}
         self._jacobian = DictionaryJacobian(system=self)
 
-        for key, dct in iteritems(self._declared_partials):
+        for key, dct in self._declared_partials.items():
             of, wrt = key
             self._declare_partials(of, wrt, dct)
 
@@ -445,9 +414,9 @@ class Component(System):
         """
         # sparsity uses relative names, so we need to convert to absolute
         pathname = self.pathname
-        for of, sub in iteritems(sparsity):
+        for of, sub in sparsity.items():
             of_abs = '.'.join((pathname, of)) if pathname else of
-            for wrt, tup in iteritems(sub):
+            for wrt, tup in sub.items():
                 wrt_abs = '.'.join((pathname, wrt)) if pathname else wrt
                 abs_key = (of_abs, wrt_abs)
                 if abs_key in self._subjacs_info:
@@ -492,15 +461,6 @@ class Component(System):
         dict
             metadata for added variable
         """
-        if units == 'unitless':
-            warn_deprecation("Input '%s' has units='unitless' but 'unitless' "
-                             "has been deprecated. Use "
-                             "units=None instead.  Note that connecting a "
-                             "unitless variable to one with units is no longer "
-                             "an error, but will issue a warning instead." %
-                             name)
-            units = None
-
         # First, type check all arguments
         if not isinstance(name, str):
             raise TypeError('%s: The name argument should be a string.' % self.msginfo)
@@ -661,15 +621,6 @@ class Component(System):
         dict
             metadata for added variable
         """
-        if units == 'unitless':
-            warn_deprecation("Output '%s' has units='unitless' but 'unitless' "
-                             "has been deprecated. Use "
-                             "units=None instead.  Note that connecting a "
-                             "unitless variable to one with units is no longer "
-                             "an error, but will issue a warning instead." %
-                             name)
-            units = None
-
         if not isinstance(name, str):
             raise TypeError('%s: The name argument should be a string.' % self.msginfo)
         if not _valid_var_name(name):
@@ -980,7 +931,7 @@ class Component(System):
                 # Check for repeated rows/cols indices.
                 idxset = set(zip(rows, cols))
                 if len(rows) - len(idxset) > 0:
-                    dups = [n for n, val in iteritems(Counter(zip(rows, cols))) if val > 1]
+                    dups = [n for n, val in Counter(zip(rows, cols)).items() if val > 1]
                     raise RuntimeError("{}: d({})/d({}): declare_partials has been called "
                                        "with rows and cols that specify the following duplicate "
                                        "subjacobian entries: {}.".format(self.msginfo, of, wrt,
@@ -1119,7 +1070,7 @@ class Component(System):
             msg = "{}: The value of 'step_calc' must be one of {}, but '{}' was specified."
             raise ValueError(msg.format(self.msginfo, supported_step_calc, step_calc))
 
-        if not isinstance(wrt, (string_types, list, tuple)):
+        if not isinstance(wrt, (str, list, tuple)):
             msg = "{}: The value of 'wrt' must be a string or list of strings, but a type " \
                   "of '{}' was provided."
             raise ValueError(msg.format(self.msginfo, type(wrt).__name__))
@@ -1129,7 +1080,7 @@ class Component(System):
                   "of '{}' was provided."
             raise ValueError(msg.format(self.msginfo, type(directional).__name__))
 
-        wrt_list = [wrt] if isinstance(wrt, string_types) else wrt
+        wrt_list = [wrt] if isinstance(wrt, str) else wrt
         self._declared_partial_checks.append((wrt_list, method, form, step, step_calc,
                                               directional))
 
@@ -1329,8 +1280,8 @@ class Component(System):
             where of_matches is a list of tuples (pattern, matches) and wrt_matches is a list of
             tuples (pattern, output_matches, input_matches).
         """
-        of_list = [of] if isinstance(of, string_types) else of
-        wrt_list = [wrt] if isinstance(wrt, string_types) else wrt
+        of_list = [of] if isinstance(of, str) else of
+        wrt_list = [wrt] if isinstance(wrt, str) else wrt
         of, wrt = self._get_potential_partials_lists()
 
         of_pattern_matches = [(pattern, find_matches(pattern, of)) for pattern in of_list]
