@@ -1,9 +1,8 @@
 """ Unit tests for the Driver base class."""
 
-from __future__ import print_function
 
 from distutils.version import LooseVersion
-from six import StringIO
+from io import StringIO
 import sys
 import unittest
 
