@@ -1,14 +1,10 @@
 """
 Unit tests for Group.
 """
-from __future__ import print_function
 
 import itertools
 import unittest
 
-from six import assertRaisesRegex, iteritems
-from six.moves import range
-
 import numpy as np
 
 try:
@@ -325,16 +321,6 @@ class TestGroup(unittest.TestCase):
         else:
             self.fail('Exception expected.')
 
-    def test_deprecated_runonce(self):
-        p = om.Problem()
-        p.model.add_subsystem('indep', om.IndepVarComp('x', 5.0))
-        p.model.add_subsystem('comp', om.ExecComp('b=2*a'))
-
-        msg = "NonLinearRunOnce is deprecated.  Use NonlinearRunOnce instead."
-
-        with assert_warning(DeprecationWarning, msg):
-            p.model.nonlinear_solver = om.NonLinearRunOnce()
-
     def test_group_simple(self):
         import openmdao.api as om
 
@@ -346,18 +332,6 @@ class TestGroup(unittest.TestCase):
         self.assertEqual(p['comp1.a'], 3.0)
         self.assertEqual(p['comp1.b'], 6.0)
 
-    def test_group_add(self):
-        model = om.Group()
-        ecomp = om.ExecComp('b=2.0*a', a=3.0, b=6.0)
-
-        msg = "The 'add' method provides backwards compatibility with OpenMDAO <= 1.x ; " \
-              "use 'add_subsystem' instead."
-
-        with assert_warning(DeprecationWarning, msg):
-            comp1 = model.add('comp1', ecomp)
-
-        self.assertTrue(ecomp is comp1)
-
     def test_group_simple_promoted(self):
         import openmdao.api as om
 
@@ -635,8 +609,12 @@ class TestGroup(unittest.TestCase):
     def test_group_promotes(self):
         """Promoting a single variable."""
         p = om.Problem()
-        p.model.add_subsystem('comp1', om.IndepVarComp([('a', 2.0), ('x', 5.0)]),
-                              promotes_outputs=['x'])
+
+        ivc = om.IndepVarComp()
+        ivc.add_output('a', 2.0)
+        ivc.add_output('x', 5.0)
+
+        p.model.add_subsystem('comp1', ivc, promotes_outputs=['x'])
         p.model.add_subsystem('comp2', om.ExecComp('y=2*x'), promotes_inputs=['x'])
         p.setup()
 
@@ -695,8 +673,12 @@ class TestGroup(unittest.TestCase):
     def test_group_promotes_multiple(self):
         """Promoting multiple variables."""
         p = om.Problem()
-        p.model.add_subsystem('comp1', om.IndepVarComp([('a', 2.0), ('x', 5.0)]),
-                              promotes_outputs=['a', 'x'])
+
+        ivc = om.IndepVarComp()
+        ivc.add_output('a', 2.0)
+        ivc.add_output('x', 5.0)
+
+        p.model.add_subsystem('comp1', ivc, promotes_outputs=['a', 'x'])
         p.model.add_subsystem('comp2', om.ExecComp('y=2*x'),
                               promotes_inputs=['x'])
         p.setup()
@@ -711,8 +693,12 @@ class TestGroup(unittest.TestCase):
     def test_group_promotes_all(self):
         """Promoting all variables with asterisk."""
         p = om.Problem()
-        p.model.add_subsystem('comp1', om.IndepVarComp([('a', 2.0), ('x', 5.0)]),
-                              promotes_outputs=['*'])
+
+        ivc = om.IndepVarComp()
+        ivc.add_output('a', 2.0)
+        ivc.add_output('x', 5.0)
+
+        p.model.add_subsystem('comp1', ivc, promotes_outputs=['*'])
         p.model.add_subsystem('comp2', om.ExecComp('y=2*x'),
                               promotes_inputs=['x'])
         p.setup()
@@ -800,7 +786,7 @@ class TestGroup(unittest.TestCase):
         G1.add_subsystem("C1", om.ExecComp("y=2.0*x"), promotes=['y'])
         G1.add_subsystem("C2", om.ExecComp("y=2.0*x"), promotes=['y'])
         msg = r"Output name 'y' refers to multiple outputs: \['G1.C1.y', 'G1.C2.y'\]."
-        with assertRaisesRegex(self, Exception, msg):
+        with self.assertRaisesRegex(Exception, msg):
             prob.setup()
 
     def test_basic_connect_units(self):
@@ -1424,7 +1410,7 @@ class TestGroup(unittest.TestCase):
 
         totals = p.check_totals(of=['discipline.comp1.z'], wrt=['parameters.input_value'], method='cs', out_stream=None)
 
-        for key, val in iteritems(totals):
+        for key, val in totals.items():
             assert_rel_error(self, val['rel error'][0], 0.0, 1e-15)
 
 
@@ -1488,28 +1474,28 @@ class TestConnect(unittest.TestCase):
         msg = "src_indices must contain integers, but src_indices for " + \
               "connection from 'src.x' to 'tgt.x' is <.* 'numpy.float64'>."
 
-        with assertRaisesRegex(self, TypeError, msg):
+        with self.assertRaisesRegex(TypeError, msg):
             self.sub.connect('src.x', 'tgt.x', src_indices=[1.0])
 
     def test_src_indices_as_float_array(self):
         msg = "src_indices must contain integers, but src_indices for " + \
               "connection from 'src.x' to 'tgt.x' is <.* 'numpy.float64'>."
 
-        with assertRaisesRegex(self, TypeError, msg):
+        with self.assertRaisesRegex(TypeError, msg):
             self.sub.connect('src.x', 'tgt.x', src_indices=np.zeros(1))
 
     def test_src_indices_as_str(self):
         msg = "src_indices must be an index array, " + \
               "did you mean connect('src.x', [tgt.x, cmp.x])?"
 
-        with assertRaisesRegex(self, TypeError, msg):
+        with self.assertRaisesRegex(TypeError, msg):
             self.sub.connect('src.x', 'tgt.x', 'cmp.x')
 
     def test_already_connected(self):
         msg = "Input 'tgt.x' is already connected to 'src.x'."
 
         self.sub.connect('src.x', 'tgt.x', src_indices=[1])
-        with assertRaisesRegex(self, RuntimeError, msg):
+        with self.assertRaisesRegex(RuntimeError, msg):
             self.sub.connect('cmp.x', 'tgt.x', src_indices=[1])
 
     def test_invalid_source(self):
@@ -1518,7 +1504,7 @@ class TestConnect(unittest.TestCase):
         # source and target names can't be checked until setup
         # because setup is not called until then
         self.sub.connect('src.z', 'tgt.x', src_indices=[1])
-        with assertRaisesRegex(self, NameError, msg):
+        with self.assertRaisesRegex(NameError, msg):
             self.prob.setup()
 
     def test_connect_to_output(self):
@@ -1527,7 +1513,7 @@ class TestConnect(unittest.TestCase):
         # source and target names can't be checked until setup
         # because setup is not called until then
         self.sub.connect('tgt.y', 'cmp.z')
-        with assertRaisesRegex(self, NameError, msg):
+        with self.assertRaisesRegex(NameError, msg):
             self.prob.setup()
 
     def test_connect_from_input(self):
@@ -1536,7 +1522,7 @@ class TestConnect(unittest.TestCase):
         # source and target names can't be checked until setup
         # because setup is not called until then
         self.sub.connect('tgt.x', 'cmp.x')
-        with assertRaisesRegex(self, NameError, msg):
+        with self.assertRaisesRegex(NameError, msg):
             self.prob.setup()
 
     def test_invalid_target(self):
@@ -1545,14 +1531,14 @@ class TestConnect(unittest.TestCase):
         # source and target names can't be checked until setup
         # because setup is not called until then
         self.sub.connect('src.x', 'tgt.z', src_indices=[1])
-        with assertRaisesRegex(self, NameError, msg):
+        with self.assertRaisesRegex(NameError, msg):
             self.prob.setup()
 
     def test_connect_within_system(self):
         msg = "Output and input are in the same System for connection " + \
               "from 'tgt.y' to 'tgt.x'."
 
-        with assertRaisesRegex(self, RuntimeError, msg):
+        with self.assertRaisesRegex(RuntimeError, msg):
             self.sub.connect('tgt.y', 'tgt.x', src_indices=[1])
 
     def test_connect_within_system_with_promotes(self):
@@ -1573,7 +1559,7 @@ class TestConnect(unittest.TestCase):
         prob = om.Problem()
         prob.model.add_subsystem('px1', om.IndepVarComp('x1', 100.0))
         prob.model.add_subsystem('src', om.ExecComp('x2 = 2 * x1', x2={'units': 'degC'}))
-        prob.model.add_subsystem('tgt', om.ExecComp('y = 3 * x', x={'units': 'unitless'}))
+        prob.model.add_subsystem('tgt', om.ExecComp('y = 3 * x', x={'units': None}))
 
         prob.model.connect('px1.x1', 'src.x1')
         prob.model.connect('src.x2', 'tgt.x')
@@ -1596,7 +1582,7 @@ class TestConnect(unittest.TestCase):
         prob.model.connect('px1.x1', 'src.x1')
         prob.model.connect('src.x2', 'tgt.x')
 
-        with assertRaisesRegex(self, RuntimeError, msg):
+        with self.assertRaisesRegex(RuntimeError, msg):
             prob.setup()
 
     def test_connect_units_with_nounits(self):
@@ -1690,7 +1676,7 @@ class TestConnect(unittest.TestCase):
         msg = ("The source and target shapes do not match or are ambiguous for the connection "
                "'sub.src.s' to 'sub.arr.x'.")
 
-        with assertRaisesRegex(self, ValueError, msg):
+        with self.assertRaisesRegex(ValueError, msg):
             self.prob.setup()
 
     def test_bad_indices_shape(self):
@@ -1704,7 +1690,7 @@ class TestConnect(unittest.TestCase):
                r"the connection 'IV.x' to 'C1.x'. The target "
                r"shape is \(2.*, 2.*\) but indices are \(1.*, 2.*\).")
 
-        with assertRaisesRegex(self, ValueError, msg):
+        with self.assertRaisesRegex(ValueError, msg):
             p.setup()
 
     def test_bad_indices_dimensions(self):
