@@ -24,7 +24,7 @@ if OPTIMIZER:
 
 
 
-@unittest.skipUnless(MPI and PETScVector, "only run with MPI and PETSc.")
+@unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class ProbRemoteTestCase(unittest.TestCase):
 
     N_PROCS = 2
@@ -82,19 +82,19 @@ class ProbRemoteTestCase(unittest.TestCase):
 
         with self.assertRaises(RuntimeError) as cm:
             loc = p.is_local('indep.x')
-        self.assertEqual(str(cm.exception), "is_local('indep.x') was called before setup() completed.")
+        self.assertEqual(str(cm.exception), "Problem: is_local('indep.x') was called before setup() completed.")
 
         with self.assertRaises(RuntimeError) as cm:
             loc = p.is_local('par.C1')
-        self.assertEqual(str(cm.exception), "is_local('par.C1') was called before setup() completed.")
+        self.assertEqual(str(cm.exception), "Problem: is_local('par.C1') was called before setup() completed.")
 
         with self.assertRaises(RuntimeError) as cm:
             loc = p.is_local('par.C1.y')
-        self.assertEqual(str(cm.exception), "is_local('par.C1.y') was called before setup() completed.")
+        self.assertEqual(str(cm.exception), "Problem: is_local('par.C1.y') was called before setup() completed.")
 
         with self.assertRaises(RuntimeError) as cm:
             loc = p.is_local('par.C1.x')
-        self.assertEqual(str(cm.exception), "is_local('par.C1.x') was called before setup() completed.")
+        self.assertEqual(str(cm.exception), "Problem: is_local('par.C1.x') was called before setup() completed.")
 
         p.setup()
         p.final_setup()
@@ -120,7 +120,7 @@ class ProbRemoteTestCase(unittest.TestCase):
             self.assertTrue(p.is_local('par.C2.y'), 'par.C2.y should be local')
 
 @unittest.skip("FIXME: test is unreliable on CI... (timeout)")
-#@unittest.skipUnless(MPI and PETScVector, "only run with MPI and PETSc.")
+#@unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class ProbRemote4TestCase(unittest.TestCase):
 
     N_PROCS = 4
