@@ -13,8 +13,7 @@ import numpy as np
 from openmdao.recorders.sqlite_recorder import blob_to_array
 from openmdao.utils.record_util import deserialize, get_source_system
 from openmdao.utils.variable_table import write_var_table
-from openmdao.utils.general_utils import warn_deprecation, make_set, \
-    match_includes_excludes
+from openmdao.utils.general_utils import make_set, match_includes_excludes
 from openmdao.utils.units import get_conversion
 
 _DEFAULT_OUT_STREAM = object()
@@ -182,19 +181,6 @@ class Case(object):
         # save VOI dict reference for use by self._scale()
         self._var_info = var_info
 
-    @property
-    def iteration_coordinate(self):
-        """
-        Deprecate the 'iteration_coordinate' attribute.
-
-        Returns
-        -------
-        str
-            The unique identifier for this case.
-        """
-        warn_deprecation("'iteration_coordinate' has been deprecated. Use 'name' instead.")
-        return self.name
-
     def __str__(self):
         """
         Get string representation of the case.
