@@ -1,8 +1,6 @@
 """
 Class definition for CaseRecorder, the base class for all recorders.
 """
-from six import iteritems
-
 from openmdao.core.system import System
 from openmdao.core.driver import Driver
 from openmdao.solvers.solver import Solver
@@ -103,9 +101,9 @@ class CaseRecorder(object):
 
         # collect scaling arrays
         scaling_vecs = {}
-        for kind, odict in iteritems(recording_requester._vectors):
+        for kind, odict in recording_requester._vectors.items():
             scaling_vecs[kind] = scaling = {}
-            for vecname, vec in iteritems(odict):
+            for vecname, vec in odict.items():
                 scaling[vecname] = vec._scaling
 
         # create a copy of the system's metadata excluding what is in 'options_excludes'
