@@ -5,11 +5,9 @@ BoundsEnforceLS - Only checks bounds and enforces them by one of three methods.
 ArmijoGoldsteinLS -- Like above, but terminates with the ArmijoGoldsteinLS condition.
 
 """
-from __future__ import print_function
 
 import sys
 import numpy as np
-from six import iteritems, reraise
 
 from openmdao.core.analysis_error import AnalysisError
 from openmdao.solvers.solver import NonlinearSolver
@@ -29,7 +27,7 @@ def _print_violations(unknowns, lower, upper):
     upper : <Vector>
         Vector containing the upper bounds.
     """
-    for name, val in iteritems(unknowns._views_flat):
+    for name, val in unknowns._views_flat.items():
         if any(val > upper._views_flat[name]):
             print("'%s' exceeds upper bounds" % name)
             print("  Val:", val)
@@ -133,8 +131,7 @@ class BoundsEnforceLS(LinesearchSolver):
 
         # Remove unused options from base options here, so that users
         # attempting to set them will get KeyErrors.
-        # "err_on_maxiter" is a deprecated option
-        for unused_option in ("atol", "rtol", "maxiter", "err_on_maxiter", "err_on_non_converge"):
+        for unused_option in ("atol", "rtol", "maxiter", "err_on_non_converge"):
             opt.undeclare(unused_option)
 
     def _solve(self):
@@ -249,8 +246,7 @@ class ArmijoGoldsteinLS(LinesearchSolver):
             if self.options['retry_on_analysis_error']:
                 self._analysis_error_raised = True
             else:
-                exc = sys.exc_info()
-                reraise(*exc)
+                raise err
 
             phi = np.nan
 
@@ -296,8 +292,7 @@ class ArmijoGoldsteinLS(LinesearchSolver):
                     self._analysis_error_raised = True
 
                 else:
-                    exc = sys.exc_info()
-                    reraise(*exc)
+                    raise err
 
             finally:
                 self._solver_info.pop()
@@ -397,8 +392,7 @@ class ArmijoGoldsteinLS(LinesearchSolver):
                         rec.rel = np.nan
 
                     else:
-                        exc = sys.exc_info()
-                        reraise(*exc)
+                        raise err
 
             # self._mpi_print(self._iter_count, norm, norm / norm0)
             self._mpi_print(self._iter_count, phi, self.alpha)
