@@ -3,17 +3,14 @@ Define the BroydenSolver class.
 
 Based on implementation in Scipy via OpenMDAO 0.8x with improvements based on NPSS solver.
 """
-from __future__ import print_function
-from six.moves import range
-
 import numpy as np
 
 from openmdao.recorders.recording_iteration_stack import Recording
+from openmdao.solvers.linesearch.backtracking import BoundsEnforceLS
 from openmdao.solvers.solver import NonlinearSolver
 from openmdao.utils.class_util import overrides_method
-from openmdao.utils.general_utils import simple_warning, warn_deprecation
+from openmdao.utils.general_utils import simple_warning
 from openmdao.utils.mpi import MPI
-from openmdao.vectors.vector import INT_DTYPE
 
 
 CITATION = """@ARTICLE{
@@ -79,7 +76,7 @@ class BroydenSolver(NonlinearSolver):
         self.linear_solver = None
 
         # Slot for linesearch
-        self.linesearch = None
+        self.linesearch = BoundsEnforceLS()
 
         self.cite = CITATION
 
@@ -133,7 +130,7 @@ class BroydenSolver(NonlinearSolver):
                              desc="Flag controls whether to perform Broyden update to the "
                                   "Jacobian. There are some applications where it may be useful "
                                   "to turn this off.")
-        self.options.declare('reraise_child_analysiserror', types=bool, default=True,
+        self.options.declare('reraise_child_analysiserror', types=bool, default=False,
                              desc='When the option is true, a solver will reraise any '
                              'AnalysisError that arises during subsolve; when false, it will '
                              'continue solving.')
@@ -160,16 +157,6 @@ class BroydenSolver(NonlinearSolver):
         rank = MPI.COMM_WORLD.rank if MPI is not None else 0
         self._disallow_discrete_outputs()
 
-        if self.options._dict['reraise_child_analysiserror']['value']:
-            pathname = self._system().pathname
-            if pathname:
-                pathname += ': '
-            msg = ("Deprecation warning: In V 3.x, reraise_child_analysiserror will default to "
-                   "False.")
-
-            if rank == 0:
-                warn_deprecation(pathname + msg)
-
         if self.linear_solver is not None:
             self.linear_solver._setup_solvers(system, self._depth + 1)
         else:
@@ -179,16 +166,6 @@ class BroydenSolver(NonlinearSolver):
             self.linesearch._setup_solvers(system, self._depth + 1)
             self.linesearch._do_subsolve = True
 
-        else:
-            # In OpenMDAO 3.x, we will be making BoundsEnforceLS the default line search.
-            # This deprecation warning is to prepare users for the change.
-            pathname = system.pathname
-            if pathname:
-                pathname += ': '
-            msg = 'Deprecation warning: In V 3.0, the default Broyden solver setup will change ' + \
-                  'to use the BoundsEnforceLS line search.'
-            warn_deprecation(pathname + msg)
-
         self._disallow_distrib_solve()
 
         states = self.options['state_vars']
