@@ -71,12 +71,11 @@ class TestNonlinearRunOnceSolver(unittest.TestCase):
         assert_rel_error(self, prob['f_xy'], 122.0)
 
 
-@unittest.skipUnless(PETScVector, "PETSc is required.")
+@unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class TestNonlinearRunOnceSolverMPI(unittest.TestCase):
 
     N_PROCS = 2
 
-    @unittest.skipUnless(MPI, "MPI is not active.")
     def test_reraise_analylsis_error(self):
         prob = om.Problem()
         model = prob.model
