@@ -1,11 +1,11 @@
-from openmdao.api import Group, Problem, MetaModelUnStructured, NearestNeighbor
+from openmdao.api import Group, Problem, MetaModelUnStructuredComp, NearestNeighbor
 from openmdao.utils.assert_utils import assert_rel_error
 
 import numpy as np
 import unittest
 
 
-class CompressorMap(MetaModelUnStructured):
+class CompressorMap(MetaModelUnStructuredComp):
 
     def __init__(self):
         super(CompressorMap, self).__init__()
