@@ -1,6 +1,3 @@
-from __future__ import division
-from six.moves import range
-
 import numpy as np
 
 import openmdao.api as om
