@@ -1,7 +1,6 @@
 """
 A console script wrapper for multiple openmdao functions.
 """
-from __future__ import print_function
 
 import sys
 import os
@@ -12,7 +11,6 @@ except ImportError:
     pkg_resources = None
 
 from itertools import chain
-from six import iteritems
 
 import openmdao.utils.hooks as hooks
 from openmdao.visualization.n2_viewer.n2_viewer import n2
@@ -41,7 +39,6 @@ from openmdao.utils.coloring import _total_coloring_setup_parser, _total_colorin
     _partial_coloring_setup_parser, _partial_coloring_cmd, \
     _view_coloring_setup_parser, _view_coloring_exec
 from openmdao.utils.scaffold import _scaffold_setup_parser, _scaffold_exec
-from openmdao.utils.general_utils import warn_deprecation
 from openmdao.utils.file_utils import _load_and_exec
 from openmdao.utils.entry_points import _list_installed_setup_parser, _list_installed_cmd, \
     split_ep, _compute_entry_points_setup_parser, _compute_entry_points_exec, \
@@ -103,11 +100,6 @@ def _n2_cmd(options, user_args):
            use_declare_partial_info=options.use_declare_partial_info)
 
 
-def _view_model_cmd(options, user_args):
-    warn_deprecation("The 'view_model' command has been deprecated. Use 'n2' instead.")
-    _n2_cmd(options, user_args)
-
-
 def _xdsm_setup_parser(parser):
     """
     Set up the openmdao subparser for the 'openmdao xdsm' command.
@@ -585,9 +577,6 @@ _command_map = {
     'view_connections': (_view_connections_setup_parser, _view_connections_cmd,
                          'View connections showing values and source/target units.'),
     'view_mm': (_meta_model_parser, _meta_model_cmd, "View a metamodel."),
-    'view_model': (_n2_setup_parser, _view_model_cmd,
-                   'Display an interactive N2 diagram of the problem. '
-                   '(Deprecated, please use n2 instead.)'),
     'xdsm': (_xdsm_setup_parser, _xdsm_cmd, 'Generate an XDSM diagram of a model.'),
 }
 
