@@ -5,15 +5,9 @@ from openmdao.utils.general_utils import remove_whitespace
 import re
 import sys
 
-from six import PY2
-
-if PY2:
-    # ASCII whitespace
-    from string import whitespace as ws
-else:
-    # Unicode whitespace
-    s = ''.join(chr(c) for c in range(sys.maxunicode+1))
-    ws = ''.join(re.findall(r'\s', s))
+# Unicode whitespace
+s = ''.join(chr(c) for c in range(sys.maxunicode+1))
+ws = ''.join(re.findall(r'\s', s))
 
 
 class TestGeneralUtils(unittest.TestCase):
