@@ -9,18 +9,13 @@ in Scientific Python, by Konrad Hinsen. Modifications by
 Justin Gray.
 """
 
-from __future__ import division, print_function
-
-
 import sys
 
 import re
 import os.path
 from collections import OrderedDict
 
-from six import iteritems
-from six.moves import zip
-from six.moves.configparser import RawConfigParser as ConfigParser
+from configparser import RawConfigParser as ConfigParser
 
 # pylint: disable=E0611, F0401
 from math import floor, pi
@@ -94,9 +89,9 @@ class NumberDict(OrderedDict):
             new NumberDict with self+other values
         """
         sum_dict = NumberDict()
-        for k, v in iteritems(self):
+        for k, v in self.items():
             sum_dict[k] = v
-        for k, v in iteritems(other):
+        for k, v in other.items():
             sum_dict[k] = sum_dict[k] + v
         return sum_dict
 
@@ -115,9 +110,9 @@ class NumberDict(OrderedDict):
             new NumberDict instance, with self-other values
         """
         sum_dict = NumberDict()
-        for k, v in iteritems(self):
+        for k, v in self.items():
             sum_dict[k] = v
-        for k, v in iteritems(other):
+        for k, v in other.items():
             sum_dict[k] = sum_dict[k] - v
         return sum_dict
 
@@ -136,9 +131,9 @@ class NumberDict(OrderedDict):
             new NumberDict instance, with other-self values
         """
         sum_dict = NumberDict()
-        for k, v in iteritems(other):
+        for k, v in other.items():
             sum_dict[k] = v
-        for k, v in iteritems(self):
+        for k, v in self.items():
             sum_dict[k] = sum_dict[k] - v
         return sum_dict
 
@@ -157,7 +152,7 @@ class NumberDict(OrderedDict):
             new NumberDict instance, with other*self values
         """
         new = NumberDict()
-        for key, value in iteritems(self):
+        for key, value in self.items():
             new[key] = other * value
         return new
 
@@ -178,7 +173,7 @@ class NumberDict(OrderedDict):
             new NumberDict instance, with self/other values
         """
         new = NumberDict()
-        for key, value in iteritems(self):
+        for key, value in self.items():
             new[key] = value / other
         return new
 
@@ -572,7 +567,7 @@ class PhysicalUnit(object):
         """
         num = ''
         denom = ''
-        for unit, power in iteritems(self._names):
+        for unit, power in self._names.items():
             if power < 0:
                 denom = denom + '/' + unit
                 if power < -1:
@@ -756,8 +751,6 @@ def import_library(libfilepointer):
                          ' config file. missing: %s, at least %s required'
                          % (missing, required_base_types))
 
-    # Explicit unitless 'unit'.
-    _new_unit('unitless', 1, list(base_list))
     _update_library(_UNIT_LIB)
     return _UNIT_LIB
 
