@@ -1,12 +1,7 @@
 """Define the default Vector class."""
-from __future__ import division
-
 from copy import deepcopy
 import numbers
 
-from six import iteritems, itervalues
-from six.moves import zip
-
 import numpy as np
 
 from openmdao.vectors.vector import Vector, INT_DTYPE
