@@ -10,7 +10,7 @@ import logging
 from bokeh.io import curdoc
 from bokeh.layouts import row, column
 from bokeh.plotting import figure
-from bokeh.models import Slider, ColumnDataSource
+from bokeh.models import Slider, ColumnDataSource, HoverTool
 from bokeh.models import ColorBar, BasicTicker, LinearColorMapper, Range1d
 from bokeh.models.widgets import TextInput, Select
 from bokeh.server.server import Server
@@ -498,11 +498,24 @@ class MetaModelVisualization(object):
         if len(data):
             # Add training data points overlay to contour plot
             data = np.array(data)
-            self.contour_training_data_source.data = dict(x=data[:, 0], y=data[:, 1])
-            self.contour_plot.circle(
+            if self.is_structured_meta_model:
+                self.contour_training_data_source.data = dict(x=data[:, 0], y=data[:, 1],
+                                                              z=self.meta_model.training_outputs[
+                                                              self.output_select.value].flatten())
+            else:
+                self.contour_training_data_source.data = dict(x=data[:, 0], y=data[:, 1],
+                                                              z=self.meta_model._training_output[
+                                                              self.output_select.value])
+
+            training_data_renderer = self.contour_plot.circle(
                 x='x', y='y', source=self.contour_training_data_source,
                 size=5, color='white', alpha=0.50)
 
+            self.contour_plot.add_tools(HoverTool(renderers=[training_data_renderer], tooltips=[
+                (self.x_input_select.value + " (train)", '@x'),
+                (self.y_input_select.value + " (train)", '@y'),
+                (self.output_select.value + " (train)", '@z'), ]))
+
         return self.contour_plot
 
     def _right_plot(self):
@@ -560,16 +573,34 @@ class MetaModelVisualization(object):
         self.right_alphas = 1.0 - data[:, 2] / self.dist_range
 
         # Training data scatter plot
+        scatter_renderer = right_plot_fig.scatter(x=data[:, 3], y=data[:, 1], line_color=None,
+                                                  fill_color='#000000',
+                                                  fill_alpha=self.right_alphas.tolist())
+
+        right_plot_fig.add_tools(HoverTool(renderers=[scatter_renderer], tooltips=[
+            (self.output_select.value + " (train)", '@x'),
+            (y_idx + " (train)", '@y'),
+        ]))
         right_plot_fig.scatter(x=data[:, 3], y=data[:, 1], line_color=None, fill_color='#000000',
                                fill_alpha=self.right_alphas.tolist())
 
+        span_width = self.dist_range * (max(y_data) - min(y_data))
+
         # Set the right_plot data source to new values
         self.right_plot_scatter_source.data = dict(
-            right_slice_x=np.repeat(x_value, self.resolution), right_slice_y=y_data)
+            right_slice_x=np.repeat(x_value, self.resolution), right_slice_y=y_data,
+            left_dashed=[i - span_width for i in np.repeat(x_value, self.resolution)],
+            right_dashed=[i + span_width for i in np.repeat(x_value, self.resolution)])
 
         self.contour_plot.line(
             'right_slice_x', 'right_slice_y', source=self.right_plot_scatter_source,
             color='black', line_width=2)
+        self.contour_plot.line(
+            'left_dashed', 'right_slice_y', line_dash='dashed',
+            source=self.right_plot_scatter_source, color='black', line_width=2)
+        self.contour_plot.line(
+            'right_dashed', 'right_slice_y', line_dash='dashed',
+            source=self.right_plot_scatter_source, color='black', line_width=2)
 
         return self.right_plot_fig
 
@@ -627,17 +658,32 @@ class MetaModelVisualization(object):
         self.bottom_alphas = 1.0 - data[:, 2] / self.dist_range
 
         # Training data scatter plot
-        bottom_plot_fig.scatter(x=data[:, 0], y=data[:, 3], line_color=None, fill_color='#000000',
-                                fill_alpha=self.bottom_alphas.tolist())
+        scatter_renderer = bottom_plot_fig.scatter(x=data[:, 0], y=data[:, 3], line_color=None,
+                                                   fill_color='#000000',
+                                                   fill_alpha=self.bottom_alphas.tolist())
+
+        bottom_plot_fig.add_tools(HoverTool(renderers=[scatter_renderer], tooltips=[
+            (x_idx + " (train)", '@x'),
+            (self.output_select.value + " (train)", '@y'),
+        ]))
+
+        span_width = self.dist_range * (max(x_data) - min(x_data))
 
         # Set the right_plot data source to new values
         self.bottom_plot_scatter_source.data = dict(
-            bot_slice_x=x_data,
-            bot_slice_y=np.repeat(y_value, self.resolution))
+            bot_slice_x=x_data, bot_slice_y=np.repeat(y_value, self.resolution),
+            upper_dashed=[i + span_width for i in np.repeat(y_value, self.resolution)],
+            lower_dashed=[i - span_width for i in np.repeat(y_value, self.resolution)])
 
         self.contour_plot.line(
             'bot_slice_x', 'bot_slice_y', source=self.bottom_plot_scatter_source, color='black',
             line_width=2)
+        self.contour_plot.line(
+            'bot_slice_x', 'upper_dashed', line_dash='dashed',
+            source=self.bottom_plot_scatter_source, color='black', line_width=2)
+        self.contour_plot.line(
+            'bot_slice_x', 'lower_dashed', line_dash='dashed',
+            source=self.bottom_plot_scatter_source, color='black', line_width=2)
 
         return self.bottom_plot_fig
 
@@ -888,7 +934,7 @@ class MetaModelVisualization(object):
         self._update_all_plots()
 
 
-def view_metamodel(meta_model_comp, resolution, port_number):
+def view_metamodel(meta_model_comp, resolution, port_number, browser):
     """
     Visualize a metamodel.
 
@@ -900,6 +946,8 @@ def view_metamodel(meta_model_comp, resolution, port_number):
         Number of points to control contour plot resolution.
     port_number : int
         Bokeh plot port number.
+    browser : bool
+        Boolean to show the browser
     """
     from bokeh.application.application import Application
     from bokeh.application.handlers import FunctionHandler
@@ -907,7 +955,10 @@ def view_metamodel(meta_model_comp, resolution, port_number):
     def make_doc(doc):
         MetaModelVisualization(meta_model_comp, resolution, doc=doc)
 
-    # print('Opening Bokeh application on http://localhost:5006/')
     server = Server({'/': Application(FunctionHandler(make_doc))}, port=int(port_number))
-    server.io_loop.add_callback(server.show, "/")
+    if browser:
+        server.io_loop.add_callback(server.show, "/")
+    else:
+        print('Server started, to view go to http://localhost:{}/'.format(port_number))
+
     server.io_loop.start()
